Index: src/org/openstreetmap/josm/gui/MainApplication.java
===================================================================
--- src/org/openstreetmap/josm/gui/MainApplication.java	(revision 17702)
+++ src/org/openstreetmap/josm/gui/MainApplication.java	(working copy)
@@ -1030,6 +1030,8 @@
         }
         // Disable automatic POST retry after 5 minutes, see #17882 / https://bugs.openjdk.java.net/browse/JDK-6382788
         Utils.updateSystemProperty("sun.net.http.retryPost", "false");
+        // Force text antialiasing, not including mappaint text
+        Utils.updateSystemProperty("awt.useSystemAAFontSettings", "on");
     }
 
     /**
Index: src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java
===================================================================
--- src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java	(revision 17702)
+++ src/org/openstreetmap/josm/gui/widgets/JosmEditorPane.java	(working copy)
@@ -3,6 +3,9 @@
 
 import java.awt.Color;
 import java.awt.Font;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.RenderingHints;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
@@ -21,8 +24,9 @@
 import org.openstreetmap.josm.tools.LanguageInfo;
 
 /**
  * Subclass of {@link JEditorPane} that adds a "native" context menu (cut/copy/paste/select all)
  * and effectively uses JOSM user agent when performing HTTP request in {@link #setPage(URL)} method.
  * @since 5886
  */
 public class JosmEditorPane extends JEditorPane implements Destroyable {
@@ -86,6 +90,16 @@
         return conn.getContent();
     }
 
+    @Override
+    public void paintComponent(Graphics g) {
+        // Force antialiasing within the JosmEditorPane for antialiased bullet points
+        Graphics2D g2d = (Graphics2D) g.create();
+        g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
+        g2d.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
+        super.paintComponent(g2d);
+        g2d.dispose();
+    }
+
     /**
      * Adapts a {@link JEditorPane} to be used as a powerful replacement of {@link javax.swing.JLabel}.
      * @param pane The editor pane to adapt
@@ -21,8 +24,9 @@
 
 /**
- * Subclass of {@link JEditorPane} that adds a "native" context menu (cut/copy/paste/select all)
- * and effectively uses JOSM user agent when performing HTTP request in {@link #setPage(URL)} method.
+ * Subclass of {@link JEditorPane} that adds a "native" context menu (cut/copy/paste/select all), forces text and bullet
+ * point antialiasing based on user preferences, and effectively uses JOSM user agent when performing HTTP request in
+ * {@link #setPage(URL)} method.
  * @since 5886
  */
